-- Custom excess heat capacity term for CpFit
-- Cp(T) = CpD(T) + a*T + b*T^2 model implementation
-- Chase M.W. et al. // Calphad Vol. 19, NO. 4, pp. 437-447, 1995
return {
	type = 'DEBPOLY',
	description = 'Debye + polynom',
	formula = 'C_p(T)=C_p^D(θ,T)+aT+bT^2',
	cpfunc = function(T, lsqparam, fixparam, Tmin, Tmax)		
		local theta = lsqparam[1]
		local a, b = lsqparam[2], lsqparam[3]
		local Natoms = fixparam[1]
		local x = theta / T
		return Natoms*CpDebye(T, theta) + a*T + b*T^2;
	end,
	lsqparam = {100, 0, 0},
	lsqparam_names = {'theta', 'a', 'b'},
	lsqparam_lb = {0,   -1e5, -1e5},
	lsqparam_ub = {1e5,  1e5,  1e5},
	fixparam = {23},	
	fixparam_names = {'Natoms'},
	Tmin = 0.0,
	Tmax = 3000.0
}
